@@ -106,7 +106,7 @@ std::string Tools::NotSupportedException::what()
 Tools::Variant::Variant()
 = default;
 
-Tools::PropertySet::PropertySet(const byte* data)
+Tools::PropertySet::PropertySet(const uint8_t* data)
 {
 	loadFromByteArray(data);
 }
@@ -116,7 +116,7 @@ Tools::PropertySet::~PropertySet()
 
 Tools::PropertySet::PropertySet()
 = default;
-void Tools::PropertySet::loadFromByteArray(const byte* ptr)
+void Tools::PropertySet::loadFromByteArray(const uint8_t* ptr)
 {
 	m_propertySet.clear();
 
@@ -136,10 +136,10 @@ void Tools::PropertySet::loadFromByteArray(const byte* ptr)
 		switch (v.m_varType)
 		{
 		case VT_SHORT:
-			int16_t s;
-			memcpy(&s, ptr, sizeof(int16_t));
+			int16_t st;
+			memcpy(&st, ptr, sizeof(int16_t));
 			ptr += sizeof(int16_t);
-			v.m_val.iVal = s;
+			v.m_val.iVal = st;
 			break;
 		case VT_LONG:
 			int32_t l;
@@ -154,9 +154,9 @@ void Tools::PropertySet::loadFromByteArray(const byte* ptr)
 			v.m_val.llVal = ll;
 			break;
 		case VT_BYTE:
-			byte b;
-			memcpy(&b, ptr, sizeof(byte));
-			ptr += sizeof(byte);
+			uint8_t b;
+			memcpy(&b, ptr, sizeof(uint8_t));
+			ptr += sizeof(uint8_t);
 			v.m_val.bVal = b;
 			break;
 		case VT_FLOAT:
@@ -196,9 +196,9 @@ void Tools::PropertySet::loadFromByteArray(const byte* ptr)
 			v.m_val.ullVal = ull;
 			break;
 		case VT_BOOL:
-			byte bl;
-			memcpy(&bl, ptr, sizeof(byte));
-			ptr += sizeof(byte);
+			uint8_t bl;
+			memcpy(&bl, ptr, sizeof(uint8_t));
+			ptr += sizeof(uint8_t);
 			v.m_val.blVal = (bl != 0);
 			break;
 		default:
@@ -229,7 +229,7 @@ uint32_t Tools::PropertySet::getByteArraySize()
 			size += sizeof(int64_t);
 			break;
 		case VT_BYTE:
-			size += sizeof(byte);
+			size += sizeof(uint8_t);
 			break;
 		case VT_FLOAT:
 			size += sizeof(float);
@@ -250,7 +250,7 @@ uint32_t Tools::PropertySet::getByteArraySize()
 			size += sizeof(uint64_t);
 			break;
 		case VT_BOOL:
-			size += sizeof(byte);
+			size += sizeof(uint8_t);
 			break;
 		default:
 			throw NotSupportedException(
@@ -263,11 +263,11 @@ uint32_t Tools::PropertySet::getByteArraySize()
 	return size;
 }
 
-void Tools::PropertySet::storeToByteArray(byte** data, uint32_t& length)
+void Tools::PropertySet::storeToByteArray(uint8_t** data, uint32_t& length)
 {
 	length = getByteArraySize();
-	*data = new byte[length];
-	byte* ptr = *data;
+	*data = new uint8_t[length];
+	uint8_t* ptr = *data;
 
 	uint32_t numberOfProperties = static_cast<uint32_t>(m_propertySet.size());
 	memcpy(ptr, &numberOfProperties, sizeof(uint32_t));
@@ -300,8 +300,8 @@ void Tools::PropertySet::storeToByteArray(byte** data, uint32_t& length)
 			ptr += sizeof(int64_t);
 			break;
 		case VT_BYTE:
-			memcpy(ptr, &((*it).second.m_val.bVal), sizeof(byte));
-			ptr += sizeof(byte);
+			memcpy(ptr, &((*it).second.m_val.bVal), sizeof(uint8_t));
+			ptr += sizeof(uint8_t);
 			break;
 		case VT_FLOAT:
 			memcpy(ptr, &((*it).second.m_val.fltVal), sizeof(float));
@@ -328,10 +328,10 @@ void Tools::PropertySet::storeToByteArray(byte** data, uint32_t& length)
 			ptr += sizeof(uint64_t);
 			break;
 		case VT_BOOL:
-			byte bl;
+			uint8_t bl;
 			bl = (*it).second.m_val.blVal;
-			memcpy(ptr, &bl, sizeof(byte));
-			ptr += sizeof(byte);
+			memcpy(ptr, &bl, sizeof(uint8_t));
+			ptr += sizeof(uint8_t);
 			break;
 		default:
 			throw NotSupportedException(
@@ -905,11 +905,11 @@ std::string Tools::BufferedFileReader::readString()
 	return ret;
 }
 
-void Tools::BufferedFileReader::readBytes(uint32_t u32Len, byte** pData)
+void Tools::BufferedFileReader::readBytes(uint32_t u32Len, uint8_t** pData)
 {
 	if (m_bEOF) throw Tools::EndOfStreamException("");
 
-	*pData = new byte[u32Len];
+	*pData = new uint8_t[u32Len];
 	m_file.read(reinterpret_cast<char*>(*pData), u32Len);
 	if (! m_file.good())
 	{
@@ -1043,7 +1043,7 @@ void Tools::BufferedFileWriter::write(const std::string& s)
 	if (! m_file.good()) throw std::ios_base::failure("");
 }
 
-void Tools::BufferedFileWriter::write(uint32_t u32Len, byte* pData)
+void Tools::BufferedFileWriter::write(uint32_t u32Len, uint8_t* pData)
 {
 	m_file.write(reinterpret_cast<const char*>(pData), u32Len);
 	if (! m_file.good()) throw std::ios_base::failure("");
@@ -1080,7 +1080,7 @@ Tools::TemporaryFile::TemporaryFile()
 
 #else
 	char tmpName[7] = "XXXXXX";
-	if (mktemp(tmpName) == nullptr)
+	if (mkstemp(tmpName) == -1)
 		throw std::ios_base::failure("Tools::TemporaryFile: Cannot create temporary file name.");
 	m_sFile = tmpName;
 #endif
@@ -1196,7 +1196,7 @@ std::string Tools::TemporaryFile::readString()
 	return br->readString();
 }
 
-void Tools::TemporaryFile::readBytes(uint32_t u32Len, byte** pData)
+void Tools::TemporaryFile::readBytes(uint32_t u32Len, uint8_t** pData)
 {
 	Tools::BufferedFileReader* br = dynamic_cast<Tools::BufferedFileReader*>(m_pFile);
 	if (br == nullptr)
@@ -1268,7 +1268,7 @@ void Tools::TemporaryFile::write(const std::string& s)
 	return bw->write(s);
 }
 
-void Tools::TemporaryFile::write(uint32_t u32Len, byte* pData)
+void Tools::TemporaryFile::write(uint32_t u32Len, uint8_t* pData)
 {
 	Tools::BufferedFileWriter* bw = dynamic_cast<Tools::BufferedFileWriter*>(m_pFile);
 	if (bw == nullptr)
